==> snortsms-0.14.9.tbz: www/snortsms/events/qry_sigzoom.php <==
<?
	
$cid = $_REQUEST['cid'];
$sid = $_REQUEST['sid'];
	
$sql = "SELECT e.sid, e.cid, e.timestamp, s.sig_name, s.sig_sid, i.*".
	" FROM event as e, signature as s, iphdr as i".
	" WHERE (e.signature = s.sig_id AND i.cid = e.cid AND i.sid = e.sid)".
	" AND (e.cid = $cid AND e.sid = $sid)";
	
//print $sql;
//exit(1);
	
	
$rsSig = $db_sa->query($sql); if (DB::isError($rsSig)) { die ($rsSig->getDebugInfo());}
$row = $rsSig->fetchRow(DB_FETCHMODE_ASSOC);
$sig['ip_proto'] = $row['ip_proto'];
$sig['sig_sid'] = $row['sig_sid'];
$sig['sig_name'] = $row['sig_name'];
$sig['timestamp'] = $row['timestamp'];
$sig['ip_src_long'] = $row['ip_src'];
$sig['ip_dst_long'] = $row['ip_dst'];
$sig['ip_src'] = long2ip($row['ip_src']);
$sig['ip_dst'] = long2ip($row['ip_dst']);
$sig['ip_ttl'] = $row['ip_ttl'];
$sig['ip_tos'] = "0x" . dechex($row['ip_tos']);
$sig['ip_len'] = $row['ip_len'];
$sig['ip_csum'] = "0x" . dechex($row['ip_csum']);

if(  $sig['ip_proto'] == 6 )
	{
	/* Get TCP Header */
	$sql = "select * FROM tcphdr WHERE cid = " . $cid . " AND sid = " . $sid;
	$rs_tcphdr = $db_sa->query($sql); if (DB::isError($rs_tcphdr)) { die ($rs_tcphdr->getDebugInfo());}
	$tcphdr = $rs_tcphdr->fetchRow(DB_FETCHMODE_ASSOC);
	$sig['port_dst'] = $tcphdr['tcp_dport'];
	$sig['port_src'] = $tcphdr['tcp_sport'];
	$sig['tcp_flags'] = $tcphdr['tcp_flags'];
	$sig['tcp_win'] = $tcphdr['tcp_win'];
	$rs_tcphdr->free();		

	}
elseif(  $sig['ip_proto'] == 17 )
	{
	/* Get UDP Header */
	$sql = "select * FROM udphdr WHERE cid = " . $cid . " AND sid = " . $sid;
	$rs_udphdr = $db_sa->query($sql); if (DB::isError($rs_udphdr)) { die ($rs_udphdr->getDebugInfo());}
	$udphdr = $rs_udphdr->fetchRow(DB_FETCHMODE_ASSOC);
	$sig['port_dst'] = $udphdr['tcp_dport'];
	$sig['port_src'] = $udphdr['tcp_sport'];
	$rs_udphdr->free();
	}


/* Get Data */
$sql = "select * FROM data WHERE cid = " . $cid . " AND sid = " . $sid;
$rs_data = $db_sa->query($sql); if (DB::isError($rs_data)) { die ($rs_data->getDebugInfo());}
$data = $rs_data->fetchRow(DB_FETCHMODE_ASSOC);
$sig['data_payload'] = $data['data_payload'];
$rs_data->free();

function PrintFlag ($flag)
	{
	$flaghex = dechex($flag);
	$output = "[0x$flaghex] ";

	if (( $flag & 32) != 0)
		{ $output .= "URG "; }
	if (( $flag & 16) != 0)
		{ $output .= "ACK "; }
	if (( $flag & 8) != 0)
		{ $output .= "PSH "; }
	if (( $flag & 4) != 0)
		{ $output .= "RST "; }
	if (( $flag & 2) != 0)
		{ $output .= "SYN "; }
	if (( $flag & 1) != 0)
		{ $output .= "FIN "; }

	return $output;
	}
	
function ShowData($payload)
	{
	$len = strlen($payload);
	$break = 0;
	$line = -1;
	$hex = $offset = $ascii = array();
	for($x = 0; $x < $len; $x=$x+2)
		{
		/* Start new line if needed */
		if(($x % 32) == 0)
			{
			$line++;
			$offset[$line] = sprintf("0x%04x: "  , $x);
			$hex[$line] = "";
			$ascii[$line] = "";
			}	
		
		$num = substr($payload, $x, 2);
		$hex[$line] .= $num . " ";
		$ascii[$line] .= SafeChar(hexdec($num));
		
		$break++;
		}
		
	/* Print each line */
	print "Payload Data:\n";
	$size = count($hex);
	for($i=0;$i<$size;$i++)
			{
			$line = $offset[$i] . " " . $hex[$i] . " " . $ascii[$i];
			$line = htmlentities($line);
			print $line . "\n";
			
			}
	}



function SafeChar($val)
	{
	if(($val >= 32) && ($val <= 126))
		{
		$char = chr($val);
		}
	else
		{
		$char = ".";
		}	
	return($char);
	}
	
	
	
	
	
	
	

	
	
	
	
	
	
?>

<BR><BR>
<CENTER>
<table border="0" class="bg1"  cellpadding="0">
<tr>
<th class="combo1">Events Details</th>

</tr>
<tr>
<td  class="bg7" >
<table border="0" cellpadding="3" cellspacing="0">
<tr class="bg2">
<td class="bold"><?=$sig['sig_name']?></td>
<td align="right"><a href="index.php?fuseaction=events.other&FRM_srcip=<?=$sig['ip_src_long']?>&FRM_dstip=<?=$sig['ip_dst_long']?>">[ Other Alerts ]</a>&nbsp;<a href="index.php?fuseaction=rules.view&FRM_sid=<?=$sig['sig_sid']?>">[View Rule]</a></td>
</tr>
<tr>
<td colspan="2">
<PRE class="large">
==========================================================================
<?=$sig['sig_name']?> [sid:<?=$sig['sig_sid']?>] 
<?=$sig['timestamp']?> <?=$sig['ip_src']?>:<?=$sig['port_src']?> -&gt; <?=$sig['ip_dst']?>:<?=$sig['port_dst']?> 
TTL:<?=$sig['ip_ttl']?> TOS:<?=$sig['ip_tos']?> IpLen:<?=$sig['ip_len']?> ChkSum:<?=$sig['ip_csum']?> 
Protocol:<?=$sig['ip_proto']?> TCP Flags:<?=PrintFlag($sig['tcp_flags'])?> Win:<?=$sig['tcp_win']?> 
--------------------------------------------------------------------------
<? ShowData($sig['data_payload']); ?>
==========================================================================

</PRE>
</td>
</tr>
<tr class="bg2" align="right">
<td colspan="2">&nbsp;</td>
</tr>
</table>


</td>
</tr>
</table>
</CENTER>

<?

$sql =	"UPDATE event".
		" SET viewed = 1".
		" WHERE cid = " . $cid . " AND sid = " . $sid;

$rsSig = $db_sa->query($sql); if (DB::isError($rsSig)) { die ($rsSig->getDebugInfo());}

?>

==> snortsms-1.0.0.tbz: www/snortsms/events/qry_sigzoom.php <==
<?
	
$cid = $_REQUEST['cid'];
$sid = $_REQUEST['sid'];
	
$sql = "SELECT e.sid, e.cid, e.timestamp, s.sig_name, s.sig_sid, i.*".
	" FROM event as e, signature as s, iphdr as i".
	" WHERE (e.signature = s.sig_id AND i.cid = e.cid AND i.sid = e.sid)".
	" AND (e.cid = $cid AND e.sid = $sid)";
	
//print $sql;
//exit(1);
	
	
$rsSig = $db_sa->query($sql); if (DB::isError($rsSig)) { die ($rsSig->getDebugInfo());}
$row = $rsSig->fetchRow(DB_FETCHMODE_ASSOC);
$sig['ip_proto'] = $row['ip_proto'];
$sig['sig_sid'] = $row['sig_sid'];
$sig['sig_name'] = $row['sig_name'];
$sig['timestamp'] = $row['timestamp'];
$sig['ip_src_long'] = $row['ip_src'];
$sig['ip_dst_long'] = $row['ip_dst'];
$sig['ip_src'] = long2ip($row['ip_src']);
$sig['ip_dst'] = long2ip($row['ip_dst']);
$sig['ip_ttl'] = $row['ip_ttl'];
$sig['ip_tos'] = "0x" . dechex($row['ip_tos']);
$sig['ip_len'] = $row['ip_len'];
$sig['ip_csum'] = "0x" . dechex($row['ip_csum']);

if(  $sig['ip_proto'] == 6 )
	{
	/* Get TCP Header */
	$sql = "select * FROM tcphdr WHERE cid = " . $cid . " AND sid = " . $sid;
	$rs_tcphdr = $db_sa->query($sql); if (DB::isError($rs_tcphdr)) { die ($rs_tcphdr->getDebugInfo());}
	$tcphdr = $rs_tcphdr->fetchRow(DB_FETCHMODE_ASSOC);
	$sig['port_dst'] = $tcphdr['tcp_dport'];
	$sig['port_src'] = $tcphdr['tcp_sport'];
	$sig['tcp_flags'] = $tcphdr['tcp_flags'];
	$sig['tcp_win'] = $tcphdr['tcp_win'];
	$rs_tcphdr->free();		

	}
elseif(  $sig['ip_proto'] == 17 )
	{
	/* Get UDP Header */
	$sql = "select * FROM udphdr WHERE cid = " . $cid . " AND sid = " . $sid;
	$rs_udphdr = $db_sa->query($sql); if (DB::isError($rs_udphdr)) { die ($rs_udphdr->getDebugInfo());}
	$udphdr = $rs_udphdr->fetchRow(DB_FETCHMODE_ASSOC);
	$sig['port_dst'] = $udphdr['tcp_dport'];
	$sig['port_src'] = $udphdr['tcp_sport'];
	$rs_udphdr->free();
	}

/* Get Data */
$sql = "select * FROM data WHERE cid = " . $cid . " AND sid = " . $sid;
$rs_data = $db_sa->query($sql); if (DB::isError($rs_data)) { die ($rs_data->getDebugInfo());}
$data = $rs_data->fetchRow(DB_FETCHMODE_ASSOC);
$sig['data_payload'] = $data['data_payload'];
$rs_data->free();

/* Get Sensor Info */
$sql = "select hostname, interface FROM sensor WHERE sid = " . $sid;
$rs_sensor = $db_sa->query($sql); if (DB::isError($rs_sensor)) { die ($rs_sensor->getDebugInfo());}
$data = $rs_sensor->fetchRow(DB_FETCHMODE_ASSOC);
$sig['sensor_name'] = $data['hostname'];
$sig['sensor_int'] = $data['interface'];
$rs_data->free();

function PrintFlag ($flag)
	{
	$flaghex = dechex($flag);
	$output = "[0x$flaghex] ";

	if (( $flag & 32) != 0)
		{ $output .= "URG "; }
	if (( $flag & 16) != 0)
		{ $output .= "ACK "; }
	if (( $flag & 8) != 0)
		{ $output .= "PSH "; }
	if (( $flag & 4) != 0)
		{ $output .= "RST "; }
	if (( $flag & 2) != 0)
		{ $output .= "SYN "; }
	if (( $flag & 1) != 0)
		{ $output .= "FIN "; }

	return $output;
	}
	
function ShowData($payload)
	{
	$len = strlen($payload);
	$break = 0;
	$line = -1;
	$hex = $offset = $ascii = array();
	for($x = 0; $x < $len; $x=$x+2)
		{
		/* Start new line if needed */
		if(($x % 32) == 0)
			{
			$line++;
			$offset[$line] = sprintf("0x%04x: "  , $x);
			$hex[$line] = "";
			$ascii[$line] = "";
			}	
		
		$num = substr($payload, $x, 2);
		$hex[$line] .= $num . " ";
		$ascii[$line] .= SafeChar(hexdec($num));
		
		$break++;
		}
		
	/* Print each line */
	print "Payload Data:\n";
	$size = count($hex);
	for($i=0;$i<$size;$i++)
			{
			$line = $offset[$i] . " " . $hex[$i] . " " . $ascii[$i];
			$line = htmlentities($line);
			print $line . "\n";
			
			}
	}



function SafeChar($val)
	{
	if(($val >= 32) && ($val <= 126))
		{
		$char = chr($val);
		}
	else
		{
		$char = ".";
		}	
	return($char);
	}
	
	
	
	
	
	
	

	
	
	
	
	
	
?>

<BR><BR>
<CENTER>
<table border="0" class="bg1"  cellpadding="0">
<tr>
<th class="combo1">Events Details</th>

</tr>
<tr>
<td  class="bg7" >
<table border="0" cellpadding="3" cellspacing="0">
<tr class="bg2">
<td class="bold" colspan="2"><?=$sig['sig_name']?></td>
</tr>
<tr class="bg2">
<td><span class="label">Sensor:</span> <?=$sig['sensor_name']?>:<?=$sig['sensor_int']?></td>
<td align="right"><a href="index.php?fuseaction=events.other&FRM_srcip=<?=$sig['ip_src_long']?>&FRM_dstip=<?=$sig['ip_dst_long']?>">[ Other Alerts ]</a>&nbsp;<a href="index.php?fuseaction=rules.view&FRM_sid=<?=$sig['sig_sid']?>">[View Rule]</a></td>
</tr>
<tr>
<td colspan="2">
<PRE class="large">
==========================================================================
<?=$sig['sig_name']?> [sid:<?=$sig['sig_sid']?>] 
<?=$sig['timestamp']?> <?=$sig['ip_src']?>:<?=$sig['port_src']?> -&gt; <?=$sig['ip_dst']?>:<?=$sig['port_dst']?> 
TTL:<?=$sig['ip_ttl']?> TOS:<?=$sig['ip_tos']?> IpLen:<?=$sig['ip_len']?> ChkSum:<?=$sig['ip_csum']?> 
Protocol:<?=$sig['ip_proto']?> TCP Flags:<?=PrintFlag($sig['tcp_flags'])?> Win:<?=$sig['tcp_win']?> 
--------------------------------------------------------------------------
<? ShowData($sig['data_payload']); ?>
==========================================================================

</PRE>
</td>
</tr>
<tr class="bg2" align="right">
<td colspan="2">&nbsp;</td>
</tr>
</table>


</td>
</tr>
</table>
</CENTER>

<?

$sql =	"UPDATE event".
		" SET viewed = 1".
		" WHERE cid = " . $cid . " AND sid = " . $sid;

$rsSig = $db_sa->query($sql); if (DB::isError($rsSig)) { die ($rsSig->getDebugInfo());}

?>
